import subprocess
import pandas as pd
from prettytable import PrettyTable

def log_analysis(start_date, end_date, process_name):
    # Define the Linux command to filter logs for the specified process within the log range
    command = f"journalctl _COMM={process_name} --since='{start_date} 00:00:00' --until='{end_date} 23:59:59'"

    # Execute the command and capture the output
    output = subprocess.check_output(command, shell=True)

    # Decode the output into a string
    output_string = output.decode("utf-8")

    # Split the output into lines and parse them into a pandas DataFrame
    log_data = [line.split(maxsplit=4) for line in output_string.split("\n") if process_name in line]
    df = pd.DataFrame(log_data, columns=["Date", "Time", "Hostname", "Process", "Message"])

    # Create a pretty table and add the data
    table = PrettyTable()
    table.field_names = ["Date", "Time", "Hostname", "Process", "Message"]
    for row in df.itertuples(index=False):
        table.add_row(row)

    # Return the formatted table as a string
    return str(table)



import setuptools


setuptools.setup(
    name="lxlog",
    version="0.3.0",
    author="selvaguru",
    author_email="your_email@example.com",
    description="A package for analyzing system log files",
    long_description_content_type="text/markdown",
    url="https://selvaguru-s.web.app",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)

